# Welcome to the Mojito framework

Mojito is a fresh, simple, and fast micro-framework for building html-first web applications and sites. 

The key features are:

* Fast: Based on Starlette, a fast and lightweight ASGI micro-framework.
* Simple to code: An intuitve API that anyone familir with Flask or FastAPI will pick up on easily.
* Batteries included: Providing helper functions to simplify repetitive tasks like auth and form processing.


# Inspirations
Mojito is built off the work done both previously and currently by projects like Flask, FastAPI, and Django.

While still a micro-framework we aim to provide you much the glue you need to get your personal or line-of-business app running in the shortest time possible.